@@ -12,11 +12,11 @@ use Memoize;
 
 =head1 VERSION
 
-Version 1.402.5
+Version 1.402.7
 
 =cut
 
-our $VERSION = '1.402.5';
+our $VERSION = '1.402.7';
 
 my %typeregistry = (
     default => {},
@@ -107,6 +107,7 @@ be found (this could be caused by updating the db).
 =cut
 
 sub clear_info_cache {
+    local $@;
     eval { Memoize::flush_cache('function_info') };
 }
 
@@ -203,8 +204,9 @@ sub function_info {
     }
 
     my $sth = $dbh->prepare($query) || die $!;
-    $sth->execute(@queryargs);
+    $sth->execute(@queryargs) || die $dbh->errstr . ": " . $query;
     my $ref = $sth->fetchrow_hashref('NAME_lc');
+    croak "transaction already aborted" if  $dbh->state eq '25P02';
     croak "No such function" if !$ref;
     croak 'Ambiguous discovery criteria' if $sth->fetchrow_hashref('NAME_lc');
 
@@ -275,6 +277,7 @@ the framework level for this parameter.
 sub call_procedure {
     my ($self) = shift @_;
     my %args = @_;
+    local $@;
     $args{funcschema} ||= 'public';
     $args{funcprefix} ||= '';
     $args{funcname} = $args{funcprefix}.$args{funcname};
@@ -282,6 +285,8 @@ sub call_procedure {
 
     my $registry = $typeregistry{$args{registry}};
     my $dbh = $args{dbh};
+    croak "No database handle provided" unless $dbh;
+    croak "dbh not a database handle" unless eval {$dbh->isa('DBI::db')};
 
     my $wf_string = '';
 
@@ -350,7 +355,7 @@ sub call_procedure {
         ++$place;
     }
 
-    $sth->execute();
+    $sth->execute() || die $dbh->errstr . ": " . $query;
     
     clear_info_cache() if $dbh->state eq '42883'; # (No Such Function)
 
@@ -382,6 +387,7 @@ This module should generally only be used by type handlers or by this module.
 
 sub process_type {
     my ($val, $type, $registry, $dbh) = @_;
+    return unless defined $val;
 
     $registry = $typeregistry{$registry} unless ref $registry;
     # Array handling as we'd get this usually from DBD::Pg or equivalent
